Module platform
atomcode_
tuix
4.23.1
Module platform
Module Items
Functions
In crate atomcode_
tuix
atomcode_tuix
Module
platform
Functions

collapse_
home
Replace a leading
$HOME
in
path
with
~
. Returns
path
unchanged if it doesn’t start under home, or if home isn’t known.
history_
path
Path for the per-user input history file. Uses ATOMCODE_HOME if set, otherwise falls back to home directory.
home_
dir
User home directory, or
None
if it can’t be determined.
image_
cache_
dir
Path for the per-user image attachment cache. Sibling to
history_path()
. Used by the History image-attachment feature to persist pasted bytes so up-arrow recall can rehydrate them on a future submit.