pub fn block_cols(rendered: &str) -> usize
Visible column count of the widest line in rendered. Both styles emit exactly one terminal cell per char, so chars().count() is the correct cell count.
rendered
chars().count()