Structs
- Task
Renderer - Renderer facade that forwards every call to a background OS thread.
Implements the
Renderertrait so the event loop can use it as a drop-in replacement forAnsiRenderer/PlainRenderer— the wire protocol is the sameUiLineenum.